@@ -5,5 +5,5 @@ from camel_model.camel_model import CamelModel
 
 class Fault(CamelModel):
     code: Optional[str]
-    involved_element: Optional[str]
     description: Optional[str]
+    observations: Optional[str]
