@@ -5,11 +5,14 @@ from openpyxl import \
     Workbook, \
     load_workbook
 
+from xlsx_lib.domain.motorcycle_model.SHEETNAMES_RELATIONSHIPS import SHEETNAMES_RELATIONSHIPS
+from xlsx_lib.domain.smart_key.SmartKeyData import SmartKeyData
+from xlsx_lib.domain.smart_key.SmartKeySheet import SmartKeySheet
 from xlsx_lib.domain.abs.AbsData import AbsData
 from xlsx_lib.domain.abs.AbsSheet import AbsSheet
 from xlsx_lib.domain.autodiagnosis.AutodiagnosisData import AutodiagnosisData
 from xlsx_lib.domain.autodiagnosis.AutodiagnosisSheet import AutodiagnosisSheet
-from xlsx_lib.domain.distribution.new_distribution_image import NewDistributionImage
+from xlsx_lib.domain.distribution.new_distribution_image import NewImage
 from xlsx_lib.domain.distribution.distribution_sheet import DistributionData, DistributionSheet
 from xlsx_lib.domain.power_supply.power_supply_component import PowerSupplyComponent
 from xlsx_lib.domain.power_supply.power_supply_sheet import PowerSupplySheet
@@ -30,18 +33,6 @@ from xlsx_lib.domain.generic_replacements.replacement import Replacement
 from xlsx_lib.domain.tightening_specifications.tightening_specifications_sheet import TighteningSpecificationsSheet
 from xlsx_lib.domain.tightening_specifications.specification_element import SpecificationElement
 
-sheetnames_relationships = {
-    "MOT": Sheetnames.ENGINE,
-    "REC. GENERICOS": Sheetnames.GENERIC_REPLACEMENTS,
-    "ELEC": Sheetnames.ELECTRONIC,
-    "PARES APRIETE": Sheetnames.TIGHTENING_TORQUES,
-    "CHAS": Sheetnames.FRAME,
-    "ALIM": Sheetnames.POWER_SUPPLY,
-    "DISTRIBUCION": Sheetnames.DISTRIBUTION,
-    "AUTODIAGNOSIS": Sheetnames.AUTODIAGNOSIS,
-    "ABS": Sheetnames.ABS,
-}
-
 
 class MotorcycleModelWorkbook:
     def __init__(
@@ -50,7 +41,8 @@ class MotorcycleModelWorkbook:
             filename: Optional[str],
     ):
         self.motorcycle_model: Optional[MotorcycleModel]
-        self.new_distribution_images: Optional[List[NewDistributionImage]] = None
+        self.distribution_images: Optional[List[NewImage]] = None
+        self.smart_key_images: Optional[List[NewImage]] = None
 
         workbook: Workbook = load_workbook(filename=file)
 
@@ -68,44 +60,50 @@ class MotorcycleModelWorkbook:
         distribution: Optional[DistributionData] = None
         autodiagnosis: Optional[AutodiagnosisData] = None
         abs_data: Optional[AbsData] = None
+        smart_key_data: Optional[SmartKeyData] = None
 
         for sheetname in [key for key in workbook.sheetnames
-                          if key in sheetnames_relationships]:
-            if Sheetnames.ENGINE == sheetnames_relationships[sheetname]:
+                          if key in SHEETNAMES_RELATIONSHIPS]:
+            if Sheetnames.ENGINE == SHEETNAMES_RELATIONSHIPS[sheetname]:
                 engine_sheet: EngineSheet = EngineSheet(worksheet=workbook[sheetname])
                 engine_sections: List[EngineSection] = engine_sheet.engine_sections
                 # TODO: Check if EngineSheet have distribution
 
-            elif Sheetnames.GENERIC_REPLACEMENTS == sheetnames_relationships[sheetname]:
+            elif Sheetnames.GENERIC_REPLACEMENTS == SHEETNAMES_RELATIONSHIPS[sheetname]:
                 generic_replacements = \
                     GenericReplacementsSheet(worksheet=workbook[sheetname]).get_generic_replacements()
 
-            elif Sheetnames.ELECTRONIC == sheetnames_relationships[sheetname]:
+            elif Sheetnames.ELECTRONIC == SHEETNAMES_RELATIONSHIPS[sheetname]:
                 electronic_elements = \
                     ElectronicSheet(worksheet=workbook[sheetname]).get_electronic_elements()
 
-            elif Sheetnames.TIGHTENING_TORQUES == sheetnames_relationships[sheetname]:
+            elif Sheetnames.TIGHTENING_TORQUES == SHEETNAMES_RELATIONSHIPS[sheetname]:
                 tightening_specifications = \
                     TighteningSpecificationsSheet(worksheet=workbook[sheetname]).get_specification_elements()
 
-            elif Sheetnames.FRAME == sheetnames_relationships[sheetname]:
+            elif Sheetnames.FRAME == SHEETNAMES_RELATIONSHIPS[sheetname]:
                 frame_elements = FrameSheet(worksheet=workbook[sheetname]).frame_elements
 
-            elif Sheetnames.POWER_SUPPLY == sheetnames_relationships[sheetname]:
+            elif Sheetnames.POWER_SUPPLY == SHEETNAMES_RELATIONSHIPS[sheetname]:
                 power_supply_components = PowerSupplySheet(worksheet=workbook[sheetname]).components
 
-            elif Sheetnames.DISTRIBUTION == sheetnames_relationships[sheetname]:
+            elif Sheetnames.DISTRIBUTION == SHEETNAMES_RELATIONSHIPS[sheetname]:
                 distribution_sheet: DistributionSheet = DistributionSheet(worksheet=workbook[sheetname])
 
                 distribution = distribution_sheet.distribution_data
-                self.new_distribution_images = distribution_sheet.new_distribution_images
+                self.distribution_images = distribution_sheet.distribution_images
 
-            elif Sheetnames.AUTODIAGNOSIS == sheetnames_relationships[sheetname]:
+            elif Sheetnames.AUTODIAGNOSIS == SHEETNAMES_RELATIONSHIPS[sheetname]:
                 autodiagnosis = AutodiagnosisSheet(worksheet=workbook[sheetname]).autodiagnosis
 
-            elif Sheetnames.ABS == sheetnames_relationships[sheetname]:
+            elif Sheetnames.ABS == SHEETNAMES_RELATIONSHIPS[sheetname]:
                 abs_data = AbsSheet(worksheet=workbook[sheetname]).abs_data
 
+            elif Sheetnames.SMART_KEY == SHEETNAMES_RELATIONSHIPS[sheetname]:
+                smart_key_sheet = SmartKeySheet(worksheet=workbook[sheetname])
+                smart_key_data = smart_key_sheet.smart_key_data
+                self.smart_key_images = smart_key_sheet.smart_key_images
+
         self.motorcycle_model = MotorcycleModel(
             model_name=model_name,
             generic_replacements=generic_replacements,
@@ -117,4 +115,5 @@ class MotorcycleModelWorkbook:
             distribution=distribution,
             autodiagnosis=autodiagnosis,
             abs_data=abs_data,
+            smart_key_data=smart_key_data
         )
